# WebLLM AI RAG Demo Configuration

This file contains example configurations and settings for the WebLLM AI RAG Demo.

## Recommended Settings

### For Development/Testing
- **Model**: Phi-3.5-mini-instruct-q4f16_1-MLC (Fast, lightweight)
- **Temperature**: 0.7
- **Max Tokens**: 1000
- **Debug Mode**: Enabled

### For Production Use
- **Model**: Llama-3.1-8B-Instruct-q4f32_1-MLC (Balanced performance)
- **Temperature**: 0.5
- **Max Tokens**: 1500
- **Debug Mode**: Disabled

## Example Test URLs

### Documentation Sites
- https://drupal.org/about
- https://webllm.mlc.ai/
- https://docs.python.org/3/tutorial/

### News and Articles
- https://blog.drupal.org/
- https://ai.googleblog.com/
- https://openai.com/blog/

### Educational Content
- https://en.wikipedia.org/wiki/Machine_learning
- https://en.wikipedia.org/wiki/Natural_language_processing
- https://en.wikipedia.org/wiki/Retrieval-augmented_generation

### Technical Blogs
- https://developers.google.com/machine-learning/guides/
- https://huggingface.co/blog/
- https://pytorch.org/blog/

## Sample Questions to Try

### General Questions
- "What is the main topic of this content?"
- "Can you summarize the key points?"
- "What are the most important details mentioned?"
- "What is the purpose of this website/article?"

### Specific Analysis
- "What features are mentioned?"
- "Are there any statistics or numbers provided?"
- "What benefits are highlighted?"
- "What challenges or problems are discussed?"

### Technical Questions
- "What technologies are mentioned?"
- "Are there any code examples or technical details?"
- "What are the system requirements?"
- "How does this work technically?"

## Performance Optimization

### Browser Settings
1. **Enable WebGPU** (Chrome/Edge):
   - Go to chrome://flags/
   - Search for "WebGPU"
   - Enable "Unsafe WebGPU" and "WebGPU Developer Features"
   - Restart browser

2. **Increase Memory Limits**:
   - Close unnecessary browser tabs
   - Ensure at least 4GB RAM available
   - Consider using a dedicated browser window

### Model Selection Guidelines
- **Small content (<1000 words)**: Any model works
- **Medium content (1000-5000 words)**: Phi 3.5 Mini or Qwen 2.5 7B
- **Large content (>5000 words)**: Llama 3.1 8B or larger

### Content Extraction Tips
- **Best Results**: Clean, well-formatted websites
- **Good Results**: News sites, blogs, documentation
- **May Need Adjustment**: Complex layouts, heavy JavaScript sites
- **Not Recommended**: Sites requiring login, dynamic content only

## Troubleshooting

### Common Issues and Solutions

1. **"Model won't load"**
   - Check available RAM (need 4-8GB free)
   - Try a smaller model first
   - Disable other browser extensions
   - Check browser console for errors

2. **"Content extraction failed"**
   - Verify URL is accessible without login
   - Try a different website
   - Check for CORS restrictions
   - Ensure stable internet connection

3. **"Slow performance"**
   - Enable WebGPU in browser
   - Use smaller model (Phi 3.5 Mini)
   - Reduce content length
   - Close other applications

4. **"AI responses are poor"**
   - Ensure content was extracted properly
   - Try adjusting temperature (0.3-0.8)
   - Use more specific questions
   - Check if content is relevant to question

## Advanced Configuration

### Custom Model Settings
```yaml
# In webllm_ai.settings.yml
models:
  custom:
    model_id: 'your-custom-model'
    name: 'Custom Model Name'
    description: 'Model description'
    memory_required: 4000  # MB
```

### API Endpoints
- Content Extraction: `POST /webllm-ai/api/extract-content`
- RAG Processing: `POST /webllm-ai/api/process-rag`
- Model List: `GET /webllm-ai/api/models`
- Health Check: `GET /webllm-ai/api/health`

### JavaScript Integration
```javascript
// Example of using the RAG API directly
fetch('/webllm-ai/api/extract-content', {
  method: 'POST',
  headers: {'Content-Type': 'application/json'},
  body: JSON.stringify({url: 'https://example.com'})
})
.then(response => response.json())
.then(data => console.log(data));
```

## Development Notes

### File Structure
```
webllm_ai/
├── src/Controller/RagDemoController.php  # Backend logic
├── js/rag-demo.js                       # Frontend JavaScript
├── css/rag-demo.css                     # Styling
├── templates/webllm-ai-rag-demo.html.twig  # Template
└── webllm_ai.routing.yml                # URL routing
```

### Key Features Implemented
- ✅ URL content extraction with cURL
- ✅ HTML-to-text conversion
- ✅ Content chunking for large texts
- ✅ RAG prompt engineering
- ✅ WebLLM model integration
- ✅ Real-time chat interface
- ✅ Progress tracking for model loading
- ✅ Error handling and user feedback
- ✅ Responsive design
- ✅ Accessibility features

### Potential Enhancements
- [ ] PDF content extraction
- [ ] Multiple document support
- [ ] Vector search integration
- [ ] Content caching system
- [ ] User session management
- [ ] Export conversation history
- [ ] Custom model fine-tuning
- [ ] Multi-language support
