# WebLLM AI RAG Demo

This demo application showcases how to use the WebLLM AI module to create a Retrieval-Augmented Generation (RAG) system that can extract content from the current webpage and answer questions about that content using AI.

## Features

- **Current Page Content Extraction**: Extract readable text content from the current webpage
- **Local AI Processing**: Uses WebLLM to run AI models directly in the browser
- **RAG Implementation**: Combines retrieved content with AI generation for accurate responses
- **No API Required**: Everything runs locally in the browser
- **Multiple AI Models**: Support for various open-source language models

## How to Use

### Step 1: Access the Demo
Navigate to any page on your Drupal site, then go to `/webllm-ai/rag-demo`.

### Step 2: Extract Current Page Content
1. Click "Extract Page Content" to analyze the current webpage
2. Review the extracted content in the preview area
3. The system will automatically identify and extract the main content

### Step 3: Load an AI Model
1. Select an AI model from the dropdown
2. Click "Load Model" to download and initialize the model
3. Wait for the model to load (this may take a few minutes for the first time)

### Step 4: Ask Questions
1. Enter questions about the current page's content
2. The AI will generate responses based on the webpage content
3. Use the suggested questions or ask your own

## Example Pages to Try

Navigate to these types of pages and then use the RAG demo:

### Documentation Pages
- Drupal module documentation pages
- API documentation
- Technical guides and tutorials

### Content Pages
- Blog posts and articles
- News articles
- Product pages
- About pages

### Educational Content
- Course materials
- Knowledge base articles
- Help documentation

## Technical Details

### RAG Process
1. **Retrieval**: Extract relevant text from the provided website
2. **Augmentation**: Create a context-aware prompt with the extracted content
3. **Generation**: Use the AI model to generate responses based on the context

### Models Supported
- Llama 3.1 8B (Recommended for balanced performance)
- Phi 3.5 Mini (Fast and lightweight)
- Qwen 2.5 7B/14B
- Gemma 2 9B
- Mistral 7B

### Browser Requirements
- **WebGPU Support**: For optimal performance (Chrome/Edge with WebGPU enabled)
- **Modern Browser**: Latest Chrome, Firefox, Safari, or Edge
- **Sufficient RAM**: At least 8GB recommended for larger models

## Use Cases

1. **Research Assistant**: Extract information from research papers or articles
2. **Documentation Helper**: Ask questions about software documentation
3. **News Analysis**: Analyze and summarize news articles
4. **Educational Tool**: Create interactive learning experiences
5. **Content Analysis**: Analyze blog posts, marketing materials, etc.

## Privacy and Security

- **No Data Sent to Servers**: All processing happens locally in your browser
- **No API Keys Required**: No external AI services used
- **Private by Design**: Your queries and content never leave your device

## Performance Tips

1. **Use WebGPU-enabled browsers** for faster model loading and inference
2. **Start with smaller models** (Phi 3.5 Mini) for testing
3. **Close other browser tabs** to free up memory for AI processing
4. **Use shorter content** for faster processing (the demo automatically truncates very long content)

## Troubleshooting

### Model Won't Load
- Ensure you have sufficient RAM available
- Try a smaller model first
- Check browser console for errors
- Verify WebGPU support in your browser

### Content Extraction Fails
- Verify the website URL is accessible
- Some websites may block automated content extraction
- Try a different website URL

### Slow Performance
- Enable WebGPU in your browser settings
- Use a smaller AI model
- Reduce the amount of extracted content

## Development

This demo is built using:
- **Drupal 10/11**: Content management system
- **WebLLM**: Browser-based AI inference
- **Custom PHP Controllers**: Content extraction and API endpoints
- **JavaScript**: Frontend interaction and AI integration
- **Modern CSS**: Responsive and accessible UI

For developers interested in extending this demo, check the source code in:
- `src/Controller/RagDemoController.php`
- `js/rag-demo.js`
- `css/rag-demo.css`
- `templates/webllm-ai-rag-demo.html.twig`
