@echo off
setlocal enabledelayedexpansion

echo 🚀 Setting up WebLLM AI RAG Demo...
echo.

REM Check if we're in a Drupal directory
if not exist "composer.json" (
    echo ❌ Error: This script must be run from the Drupal root directory.
    echo    Make sure you're in the directory containing composer.json and web\ folder.
    pause
    exit /b 1
)

if not exist "web" (
    echo ❌ Error: This script must be run from the Drupal root directory.
    echo    Make sure you're in the directory containing composer.json and web\ folder.
    pause
    exit /b 1
)

REM Check if webllm_ai module exists
if not exist "webllm_ai" (
    echo ❌ Error: webllm_ai module not found in current directory.
    echo    Please ensure the webllm_ai module is in the current directory.
    pause
    exit /b 1
)

echo ✅ Found Drupal installation and webllm_ai module
echo.

REM Copy the module to the modules directory if not already there
if not exist "web\modules\custom\webllm_ai" (
    echo 📁 Creating modules\custom directory...
    if not exist "web\modules\custom" mkdir "web\modules\custom"
    
    echo 📁 Copying webllm_ai module to web\modules\custom\...
    xcopy "webllm_ai" "web\modules\custom\webllm_ai" /E /I /Y >nul
    echo ✅ Module copied successfully
    echo.
)

REM Enable the module using Drush if available
if exist "vendor\bin\drush.bat" (
    echo 🔧 Enabling webllm_ai module with Drush...
    vendor\bin\drush.bat en webllm_ai -y
    
    echo 🧹 Clearing cache...
    vendor\bin\drush.bat cr
    
    echo ✅ Module enabled and cache cleared
    echo.
) else (
    echo ⚠️  Drush not found. Please enable the webllm_ai module manually:
    echo    - Go to /admin/modules
    echo    - Find 'WebLLM AI' in the AI/Machine Learning section
    echo    - Check the box and click 'Install'
    echo.
)

REM Instructions for users
echo 🎉 Setup Complete!
echo.
echo 📋 Next Steps:
echo 1. Enable the webllm_ai module (if not done automatically)
echo 2. Go to /admin/config/system/webllm-ai to configure settings
echo 3. Visit /webllm-ai/rag-demo to try the RAG demo
echo.
echo 🌐 Demo URLs:
echo    • RAG Demo: /webllm-ai/rag-demo
echo    • Basic Demo: /webllm-ai/demo
echo    • Settings: /admin/config/system/webllm-ai
echo.
echo 📚 For detailed instructions, see RAG_DEMO_README.md
echo.
echo 🎯 Try these example URLs in the RAG demo:
echo    • https://drupal.org/about
echo    • https://webllm.mlc.ai/
echo    • https://en.wikipedia.org/wiki/Artificial_intelligence
echo.

REM Check if site is running (basic check)
ping -n 1 localhost >nul 2>&1
if !errorlevel! equ 0 (
    echo 🌐 Your site may be running locally
    echo    You can try accessing the RAG demo at: http://localhost/webllm-ai/rag-demo
) else (
    echo ⚠️  Please make sure your local development server is running
    echo    and then access the demo at your site's URL + /webllm-ai/rag-demo
)

echo.
echo Happy coding! 🤖✨
echo.
pause
