@echo off
REM WebLLM AI Module Installation Script for Windows
REM 
REM Instructions:
REM 1. Copy this script to your Drupal root directory
REM 2. Copy the webllm_ai folder to modules/custom/
REM 3. Run this script from PowerShell or Command Prompt
REM 4. Or use the web interface at /admin/modules

echo ==========================================
echo WebLLM AI Module Installation
echo ==========================================
echo.

REM Check if we're in a Drupal directory
if not exist "web\index.php" if not exist "index.php" (
    echo ERROR: This doesn't appear to be a Drupal root directory.
    echo Please run this script from your Drupal installation root.
    echo.
    echo Expected structure:
    echo   - Drupal root/
    echo     - web/ ^(or index.php in root^)
    echo     - modules/
    echo     - vendor/
    echo.
    pause
    exit /b 1
)

echo Found Drupal installation!
echo.

REM Check for Drush
echo Checking for Drush...
where drush >nul 2>&1
if %errorlevel% == 0 (
    echo Drush found globally!
    drush en webllm_ai
    drush cr
    echo.
    echo Module enabled successfully!
    echo Configure it at: /admin/config/system/webllm-ai
) else (
    if exist "vendor\bin\drush.bat" (
        echo Drush found locally!
        vendor\bin\drush en webllm_ai
        vendor\bin\drush cr
        echo.
        echo Module enabled successfully!
        echo Configure it at: /admin/config/system/webllm-ai
    ) else (
        echo Drush not found. Please enable the module manually:
        echo.
        echo 1. Copy webllm_ai folder to modules/custom/
        echo 2. Go to /admin/modules in your Drupal site
        echo 3. Find "Web-LLM AI" and enable it
        echo 4. Configure at /admin/config/system/webllm-ai
        echo.
        echo Alternative: Install Drush with:
        echo   composer require drush/drush
    )
)

echo.
echo ==========================================
echo Installation complete!
echo ==========================================
pause
