#!/bin/bash

# WebLLM AI RAG Demo Quick Start Script

echo "🚀 Setting up WebLLM AI RAG Demo..."
echo ""

# Check if we're in a Drupal directory
if [ ! -f "composer.json" ] || [ ! -d "web" ]; then
    echo "❌ Error: This script must be run from the Drupal root directory."
    echo "   Make sure you're in the directory containing composer.json and web/ folder."
    exit 1
fi

# Check if webllm_ai module exists
if [ ! -d "webllm_ai" ]; then
    echo "❌ Error: webllm_ai module not found in current directory."
    echo "   Please ensure the webllm_ai module is in the current directory."
    exit 1
fi

echo "✅ Found Drupal installation and webllm_ai module"
echo ""

# Copy the module to the modules directory if not already there
if [ ! -d "web/modules/custom/webllm_ai" ]; then
    echo "📁 Creating modules/custom directory..."
    mkdir -p web/modules/custom
    
    echo "📁 Copying webllm_ai module to web/modules/custom/..."
    cp -r webllm_ai web/modules/custom/
    echo "✅ Module copied successfully"
    echo ""
fi

# Enable the module using Drush if available
if command -v ./vendor/bin/drush &> /dev/null; then
    echo "🔧 Enabling webllm_ai module with Drush..."
    ./vendor/bin/drush en webllm_ai -y
    
    echo "🧹 Clearing cache..."
    ./vendor/bin/drush cr
    
    echo "✅ Module enabled and cache cleared"
    echo ""
else
    echo "⚠️  Drush not found. Please enable the webllm_ai module manually:"
    echo "   - Go to /admin/modules"
    echo "   - Find 'WebLLM AI' in the AI/Machine Learning section"
    echo "   - Check the box and click 'Install'"
    echo ""
fi

# Instructions for users
echo "🎉 Setup Complete!"
echo ""
echo "📋 Next Steps:"
echo "1. Enable the webllm_ai module (if not done automatically)"
echo "2. Go to /admin/config/system/webllm-ai to configure settings"
echo "3. Visit /webllm-ai/rag-demo to try the RAG demo"
echo ""
echo "🌐 Demo URLs:"
echo "   • RAG Demo: /webllm-ai/rag-demo"
echo "   • Basic Demo: /webllm-ai/demo"
echo "   • Settings: /admin/config/system/webllm-ai"
echo ""
echo "📚 For detailed instructions, see RAG_DEMO_README.md"
echo ""
echo "🎯 Try these example URLs in the RAG demo:"
echo "   • https://drupal.org/about"
echo "   • https://webllm.mlc.ai/"
echo "   • https://en.wikipedia.org/wiki/Artificial_intelligence"
echo ""

# Check if site is running
if command -v curl &> /dev/null; then
    if curl -s --head http://localhost | head -n 1 | grep -q "200 OK"; then
        echo "🌐 Your site appears to be running at http://localhost"
        echo "   You can access the RAG demo at: http://localhost/webllm-ai/rag-demo"
    else
        echo "⚠️  Your site doesn't appear to be running on http://localhost"
        echo "   Please start your local development server and then access the demo"
    fi
fi

echo ""
echo "Happy coding! 🤖✨"
