<?php

namespace Drupal\webllm_ai\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\webllm_ai\Service\WebLlmService;
use Drupal\webllm_ai\Service\ModelManager;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller for Web-LLM AI main pages.
 */
class WebLLMController extends ControllerBase {
  /**
   * The Web-LLM service.
   *
   * @var \Drupal\webllm_ai\Service\WebLlmService
   */
  protected $webllmService;

  /**
   * The model manager service.
   *
   * @var \Drupal\webllm_ai\Service\ModelManager
   */
  protected $modelManager;

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**   * Constructs a new WebLLMController object.
   *
   * @param \Drupal\webllm_ai\Service\WebLlmService $webllm_service
   *   The Web-LLM service.
   * @param \Drupal\webllm_ai\Service\ModelManager $model_manager
   *   The model manager service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(WebLlmService $webllm_service, ModelManager $model_manager, ConfigFactoryInterface $config_factory) {
    $this->webllmService = $webllm_service;
    $this->modelManager = $model_manager;
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('webllm_ai.service'),
      $container->get('webllm_ai.model_manager'),
      $container->get('config.factory')
    );
  }

  /**
   * Demo page for Web-LLM AI.
   *
   * @return array
   *   A render array.
   */
  public function demo() {
    $config = $this->configFactory->get('webllm_ai.settings');
    
    if (!$config->get('enabled')) {
      $this->messenger()->addWarning($this->t('Web-LLM AI module is currently disabled. Please enable it in the settings.'));
    }    $build = [
      '#theme' => 'webllm_ai_demo',
      '#attached' => [
        'library' => ['webllm_ai/webllm-chat'],
        'drupalSettings' => [
          'webllm_ai' => [
            'enabled' => $config->get('enabled'),
            'default_model' => $config->get('default_model'),
            'max_tokens' => $config->get('max_tokens'),
            'temperature' => $config->get('temperature'),
            'debug_mode' => $config->get('debug_mode'),
            'api_endpoints' => [
              'models' => '/webllm-ai/api/models',
              'config' => '/webllm-ai/api/config',
              'health' => '/webllm-ai/api/health',
              'progress' => '/webllm-ai/api/model-progress',
              'clear_cache' => '/webllm-ai/api/clear-cache',
            ],
          ],
        ],
      ],
      '#cache' => [
        'contexts' => ['user.permissions'],
        'tags' => ['config:webllm_ai.settings'],
        'max-age' => 3600,
      ],
    ];

    return $build;
  }

  /**
   * Model management page.
   *
   * @return array
   *   A render array.
   */
  public function models() {
    $models = $this->modelManager->getAvailableModels();
    
    $build = [
      '#theme' => 'webllm_ai_models',      '#models' => $models,
      '#attached' => [
        'library' => ['webllm_ai/webllm-admin'],
      ],
      '#cache' => [
        'contexts' => ['user.permissions'],
        'tags' => ['webllm_ai_models'],
        'max-age' => 3600,
      ],
    ];

    return $build;
  }

}
